Skip to contents

Returns a vector of years for which graduation rate data is available from the Florida Department of Education.

Usage

get_available_grad_years()

Value

Integer vector of years (2016, 2017, ..., 2024)

Examples

if (FALSE) { # \dontrun{
get_available_grad_years()
# Returns: 2016 2017 2018 2019 2020 2021 2022 2023 2024
} # }